pub fn get_input(
prompt: &str,
default_value: Option<&str>,
echo: bool,
verify: bool
) -> Option<String>Expand description
A utility function that will prompt the user for input via the console/tty.
prompt is the text to show to the user.
default_value can be used to pre-set the answer, allowing the
user to simply press enter.
echo, if true, means to show the user’s answer on the screen
as they type it. If false, means to conceal it.
verify, if true, will ask the user for their input twice in
order to confirm that they provided the same text both times.
This is useful when creating a password and echo == false.