pub struct Sftp { /* private fields */ }Implementations
Create a directory.
mode specifies the permission bits to use on the directory.
They will be modified by the effective umask on the server.
Canonicalize filename, resolving relative directory references
and symlinks.
Change the permissions of a file
Change the ownership of a file.
Change certain metadata attributes of the named file.
Retrieve metadata for a file, traversing symlinks
Retrieve metadata for a file, without traversing symlinks.
Rename a file from filename to new_name
Remove a file or an empty directory
Remove an empty directory
Create a symlink on the server.
target is the filename of the symlink to be created,
and dest is the payload of the symlink.
Open a file on the server.
accesstype corresponds to the open(2) flags parameter
and controls whether the file is opened for read/write and so on.
mode specified the permission bits to use when creating a new file;
they will be modified by the effective umask on the server side.
Open a directory to obtain directory entries